setwd("")

library("ape")
library("pegas")
library("seqinr")
library("ggplot2")
library("adegenet")
library("poppr")

###########################################################################
################# two populations of Lygus borealis #######################
###########################################################################

###### Read structure data into R as a genind object
Bor.genind = import2genind('Lygus_18u_Borealis.str', onerowperind=F, n.ind=8, n.loc=965, row.marknames=NULL, col.lab=1, ask=F)

#HWE <- hw.test(Bor.genind, B = 1000)
#write.table(HWE, "BorealisHWE.txt", sep="\t")

#### Convert Bor.genind to genclone
Bor.genclone = as.genclone(Bor.genind)


##### Read in hierarchy file
Bor.hier = read.table('LygusMin10_Borealis_Hier.txt', header=T)

#### Add hierarchy file
strata(Bor.genind) = Bor.hier
Borealis.strat = as.genclone(Bor.genind)

#### Borealis differences between localities
Bor.locality.amova.res = poppr.amova(Borealis.strat, ~Locality, cutoff=0.95)
Bor.locality.amova.res
Bor.locality.amova.test = randtest(Bor.locality.amova.res)
str(Bor.locality.amova.test)
plot(Bor.locality.amova.test)
Bor.locality.amova.test

#### Borealis differences between dates
Bor.date.amova.res = poppr.amova(Borealis.strat, ~Date, cutoff=0.95)
Bor.date.amova.res
Bor.date.amova.test = randtest(Bor.date.amova.res)
str(Bor.date.amova.test)
plot(Bor.date.amova.test)
Bor.date.amova.test

###########################################################################
################# Lygus elisus ############################################
###########################################################################

###### Read structure data into R as a genind object
Eli.genind = import2genind('LygusMin10_Elisus.str', onerowperind=F, n.ind=4, n.loc=1453, row.marknames=NULL, col.lab=1, ask=F)

HWE <- hw.test(Eli.genind, B = 1000)
write.table(HWE, "EliHWE.txt", sep="\t")

#### Convert Eli.genind to genclone
Eli.genclone = as.genclone(Eli.genind)

##### Read in hierarchy file
Eli.hier = read.table('LygusMin10_Elisus_Hier.txt', header=T)

#### Add hierarchy file
strata(Eli.genind) = Eli.hier
Elisus.strat = as.genclone(Eli.genind)

#### Elisus between different plants
Eli.plant.amova.res = poppr.amova(Elisus.strat, ~Plant, cutoff=0.95)
Eli.plant.amova.res
Eli.plant.amova.test = randtest(Eli.plant.amova.res)
str(Eli.plant.amova.test)
plot(Eli.plant.amova.test)
Eli.plant.amova.test

#### Elisus between different dates
Eli.date.amova.res = poppr.amova(Elisus.strat, ~Date, cutoff=0.95)
Eli.date.amova.res
Eli.date.amova.test = randtest(Eli.date.amova.res)
str(Eli.date.amova.test)
plot(Eli.date.amova.test)
Eli.date.amova.test

############################################################################
##########################Lygus keltoni#####################################
############################################################################

###### Read structure data into R as a genind object
Kel.genind = import2genind('LygusMin10_Keltoni.str', onerowperind=F, n.ind=4, n.loc=1453, row.marknames=NULL, col.lab=1, ask=F)

HWE <- hw.test(Kel.genind, B = 1000)
write.table(HWE, "KelHWE.txt", sep="\t")

#### Convert Kel.genind to genclone
Kel.genclone = as.genclone(Kel.genind)

##### Read in hierarchy file
Kel.hier = read.table('LygusMin10_Keltoni_Hier.txt', header=T)

#### Add hierarchy file
strata(Kel.genind) = Kel.hier
Keltoni.strat = as.genclone(Kel.genind)

#### Keltoni differences between different plants
Kel.plant.amova.res = poppr.amova(Keltoni.strat, ~Plant, cutoff=0.95)
Kel.plant.amova.res
Kel.plant.amova.test = randtest(Kel.plant.amova.res)
str(Kel.plant.amova.test)
plot(Kel.plant.amova.test)
Kel.plant.amova.test

#### Keltoni differences between different dates
Kel.date.amova.res = poppr.amova(Keltoni.strat, ~Date, cutoff=0.95)
Kel.date.amova.res
Kel.date.amova.test = randtest(Kel.date.amova.res)
str(Kel.date.amova.test)
plot(Kel.date.amova.test)
Kel.date.amova.test