setwd("")

library("ape")
library("pegas")
library("seqinr")
library("ggplot2")
library("adegenet")
library("poppr")

#######################################################################
#############two populations of Peristenus Mellipes ###################
#######################################################################

###### Read structure data into R as a genind object
Mell.genind = import2genind('Peri_19u_mellipes.str', onerowperind=F, n.ind=11, n.loc=15456, row.marknames=NULL, col.lab=1, ask=F)

#HWE <- hw.test(Mell.genind, B = 1000)
#write.table(HWE, "MelHWE.txt", sep="\t")

#### Convert Mell.genind to genclone
Mell.genclone = as.genclone(Mell.genind)

##### Read in hierarchy file
Mell.hier = read.table('PeriMin10_Mellipes_Hier.txt', header=T)

#### Add hierarchy file
strata(Mell.genind) = Mell.hier
Mellipes.strat = as.genclone(Mell.genind)

#### Mellipes differences between bugs
Mell.bug.amova.res = poppr.amova(Mellipes.strat, ~Bug, cutoff=0.95)
Mell.bug.amova.res
Mell.bug.amova.test = randtest(Mell.bug.amova.res)
str(Mell.bug.amova.test)
plot(Mell.bug.amova.test)
Mell.bug.amova.test

#### Mellipes differences between localities
Mell.locality.amova.res = poppr.amova(Mellipes.strat, ~Locality, cutoff=0.95)
Mell.locality.amova.res
Mell.locality.amova.test = randtest(Mell.locality.amova.res)
str(Mell.locality.amova.test)
plot(Mell.locality.amova.test)
Mell.locality.amova.test

#### Mellipes bugs within locality
Mell.bughier.amova.res = poppr.amova(Mellipes.strat, ~Locality/Bug, cutoff=0.95)
Mell.bughier.amova.res
Mell.bughier.amova.test = randtest(Mell.bughier.amova.res)
str(Mell.bughier.amova.test)
plot(Mell.bughier.amova.test)
Mell.bug.amova.test

#### Mellipes locality within bugs
Mell.localityhier.amova.res = poppr.amova(Mellipes.strat, ~Locality/Bug, cutoff=0.95)
Mell.localityhier.amova.res
Mell.localityhier.amova.test = randtest(Mell.localityhier.amova.res)
str(Mell.localityhier.amova.test)
plot(Mell.localityhier.amova.test)
Mell.localityhier.amova.test

#### Mellipes differences between plants
Mell.plant.amova.res = poppr.amova(Mellipes.strat, ~Plant, cutoff=0.95)
Mell.plant.amova.res
Mell.plant.amova.test = randtest(Mell.plant.amova.res)
str(Mell.plant.amova.test)
plot(Mell.plant.amova.test)
Mell.plant.amova.test

##########################################################################
##########################Peristenus howardi #############################
##########################################################################

###### Read structure data into R as a genind object
how.genind = import2genind('Peri_19u_howardi.str', onerowperind=F, n.ind=6, n.loc=15456, row.marknames=NULL, col.lab=1, ask=F)

#HWE <- hw.test(how.genind, B = 1000)
#write.table(HWE, "HowHWE.txt", sep="\t")

#### Convert how.genind to genclone
how.genclone = as.genclone(how.genind)

##### Read in hierarchy file
how.hier = read.table('PeriMin10_Howardi_Hier.txt', header=T)

#### Add hierarchy file
strata(how.genind) = how.hier
howardi.strat = as.genclone(how.genind)

#### Howardi differences between bugs
how.bug.amova.res = poppr.amova(howardi.strat, ~Bug, cutoff=0.95)
how.bug.amova.res
how.bug.amova.test = randtest(how.bug.amova.res)
str(how.bug.amova.test)
plot(how.bug.amova.test)
how.bug.amova.test

#### Howardi differences between plants
how.plant.amova.res = poppr.amova(howardi.strat, ~Plant, cutoff=0.95)
how.plant.amova.res
how.plant.amova.test = randtest(how.plant.amova.res)
str(how.plant.amova.test)
plot(how.plant.amova.test)
how.plant.amova.test